
These changes are listed in decreasing version number order.


Release 0.3
-----------

Release date was |today|


Release 0.2
-----------

December 31th, 2017


Release 0.1
-----------

Release date was July 7th, 2017